@@ -89,6 +89,7 @@ struct TileDBWriter::Args
     bool m_use_time;
     bool m_time_first;
     bool m_combine_bit_fields;
+    bool m_allow_dups;
     uint64_t m_timeStamp = UINT64_MAX;
 };
 
@@ -139,22 +140,22 @@ void TileDBWriter::addArgs(ProgramArgs& args)
                      m_args->m_time_domain_end, 0.0);
     args.add<double>("scale_x",
                      "Scale factor to use for default x float-scale filter",
-                     m_args->m_scale[0], 0.01);
+                     m_args->m_scale[0], std::numeric_limits<double>::quiet_NaN());
     args.add<double>("scale_y",
                      "Scale factor to use for default y float-scale fitler",
-                     m_args->m_scale[1], 0.01);
+                     m_args->m_scale[1], std::numeric_limits<double>::quiet_NaN());
     args.add<double>("scale_z",
                      "Scale factor to use for default z float-scale filter",
-                     m_args->m_scale[2], 0.01);
+                     m_args->m_scale[2], std::numeric_limits<double>::quiet_NaN());
     args.add<double>("offset_x",
                      "Add offset to use for default x float-scale filter",
-                     m_args->m_offset[0], 0.0);
+                     m_args->m_offset[0], std::numeric_limits<double>::quiet_NaN());
     args.add<double>("offset_y",
                      "Add offset to use for default y float-scale filter",
-                     m_args->m_offset[1], 0.0);
+                     m_args->m_offset[1], std::numeric_limits<double>::quiet_NaN());
     args.add<double>("offset_z",
                      "Add offset to use fo default x float-scale filter",
-                     m_args->m_offset[2], 0.0);
+                     m_args->m_offset[2], std::numeric_limits<double>::quiet_NaN());
     args.add("chunk_size", "Point cache size for chunked writes",
              m_args->m_cache_size, size_t(1000000));
     args.add("stats", "Dump TileDB query stats to stdout", m_args->m_stats,
@@ -181,6 +182,9 @@ void TileDBWriter::addArgs(ProgramArgs& args)
     args.add("combine_bit_fields",
              "Combine all bit fields into a single 2 byte attribute",
              m_args->m_combine_bit_fields, true);
+    args.add("allow_dups", "Allow duplicate points (default is True)", m_args->m_allow_dups,
+             true);
+
 }
 
 void TileDBWriter::initialize()
@@ -289,7 +293,7 @@ void TileDBWriter::ready(pdal::BasePointTable& table)
 
         // Create schema and set basic properties.
         tiledb::ArraySchema schema{*m_ctx, TILEDB_SPARSE};
-        schema.set_allows_dups(true);
+        schema.set_allows_dups(m_args->m_allow_dups);
         schema.set_capacity(m_args->m_tile_capacity);
 
         // Set tile order.
@@ -337,6 +341,44 @@ void TileDBWriter::ready(pdal::BasePointTable& table)
             throwError("Invalid cell order option '" + m_args->m_cell_order +
                        "'.");
 
+        MetadataNode meta = table.metadata().findChild("filters.stats:bbox:native:bbox");
+        if (!meta.valid())
+        {
+            meta = table.metadata().findChild("readers.las");
+        }
+
+        auto updateWithMeta = [&](const std::string& key, double& val)
+        {
+            val = meta.findChild(key).value<double>();
+        };
+
+        if (std::isnan(m_args->m_offset[0]))
+        {
+            if (meta.valid() && meta.findChild("offset_x").valid())
+            {
+                    updateWithMeta("offset_x", m_args->m_offset[0]);
+                    updateWithMeta("offset_y", m_args->m_offset[1]);
+                    updateWithMeta("offset_z", m_args->m_offset[2]);
+            }
+            else
+            {
+                m_args->m_offset = {0.0, 0.0, 0.0};
+            }
+        }
+
+        if (std::isnan(m_args->m_scale[0]))
+        {
+            if (meta.valid() && meta.findChild("scale_x").valid())
+            {
+                updateWithMeta("scale_x", m_args->m_scale[0]);
+                updateWithMeta("scale_y", m_args->m_scale[1]);
+                updateWithMeta("scale_z", m_args->m_scale[2]);
+            }
+            else
+            {
+                m_args->m_scale = {0.01, 0.01, 0.01};
+            }
+        }
         // Get filter factory class.
         FilterFactory filterFactory{
             m_args->m_filters,    m_args->m_filter_profile,
@@ -363,28 +405,27 @@ void TileDBWriter::ready(pdal::BasePointTable& table)
              {m_args->m_time_domain_st, m_args->m_time_domain_end}}};
 
         // If X, Y, or Z domain are not valid, then attempt to update with
-        // the stats filter bbox.
+        // the stats filter or quickinfo bbox. If bounds are not specified
+        // also check for offset and scales in the LAS header
         if (bbox[0][1] <= bbox[0][0] || bbox[1][1] <= bbox[1][0] ||
             bbox[2][1] <= bbox[2][0])
         {
+            // Check if we can update with stats filter, fallback to quickinfo if not
+            auto updateMinMaxWithMeta = [&](const std::string& minStr,
+                                        const std::string& maxStr,
+                                        std::array<double, 2>& range)
+            {
+                if (range[1] <= range[0])
+                    range = {meta.findChild(minStr).value<double>() - 1.0,
+                                meta.findChild(maxStr).value<double>() + 1.0};
+            };
 
-            // Check if we can update with
-            MetadataNode meta =
-                table.metadata().findChild("filters.stats:bbox:native:bbox");
             if (meta.valid())
             {
-                // Update any missing domains using table statistics.
-                auto updateWithStats = [&](const std::string& minStr,
-                                           const std::string& maxStr,
-                                           std::array<double, 2>& range)
-                {
-                    if (range[1] <= range[0])
-                        range = {meta.findChild(minStr).value<double>() - 1.0,
-                                 meta.findChild(maxStr).value<double>() + 1.0};
-                };
-                updateWithStats("minx", "maxx", bbox[0]);
-                updateWithStats("miny", "maxy", bbox[1]);
-                updateWithStats("minz", "maxz", bbox[2]);
+                // Update any missing domains
+                updateMinMaxWithMeta("minx", "maxx", bbox[0]);
+                updateMinMaxWithMeta("miny", "maxy", bbox[1]);
+                updateMinMaxWithMeta("minz", "maxz", bbox[2]);
             }
         }
 
